//header_area css
.header_area {
	position: absolute;
	width: 100%;
	top: 0;
	left: 0;
	z-index: 99;
	transition: background 0.4s, all 0.3s linear;

	.navbar {
		background: transparent;
		padding: 0px;
		border: 0px;
		border-radius: 0px;
		.nav {
			.nav-item {
				margin-right: 45px;
				.nav-link {
					font: 500 13px/100px $text-font;
					text-transform: uppercase;
					color: $title-color;
					padding: 0px;
					display: inline-block;
					&:after {
						display: none;
					}
				}
				&:hover,
				&.active {
					.nav-link {
						color: $baseColor !important;
					}
				}
				&.submenu {
					position: relative;
					ul {
						border: none;
						padding: 0px;
						border-radius: 0px;
						box-shadow: none;
						margin: 0px;
						background: #fff;
						box-shadow: 0px 3px 16px 0px rgba(0, 0, 0, 0.1);
						@media (min-width: 992px) {
							position: absolute;
							top: 120%;
							left: 0px;
							min-width: 200px;
							text-align: left;
							opacity: 0;
							transition: all 300ms ease-in;
							visibility: hidden;
							display: block;
							border: none;
							padding: 0px;
							border-radius: 0px;
						}
						&:before {
							content: "";
							width: 0;
							height: 0;
							border-style: solid;
							border-width: 10px 10px 0 10px;
							border-color: #eeeeee transparent transparent transparent;
							position: absolute;
							right: 24px;
							top: 45px;
							z-index: 3;
							opacity: 0;
							transition: all 400ms linear;
						}
						.nav-item {
							display: block;
							float: none;
							margin-right: 0px;
							border-bottom: 1px solid #ededed;
							margin-left: 0px;
							transition: all 0.4s linear;
							.nav-link {
								line-height: 45px;
								color: $title-color !important;
								padding: 0px 30px;
								transition: all 150ms linear;
								display: block;
								margin-right: 0px;
							}
							&:last-child {
								border-bottom: none;
							}
							&:hover {
								.nav-link {
									background: $baseColor;
									color: #fff !important;
								}
							}
						}
					}
					&:hover {
						ul {
							@media (min-width: 992px) {
								visibility: visible;
								opacity: 1;
								top: 100%;
							}
							.nav-item {
								margin-top: 0px;
							}
						}
					}
				}
				&:last-child {
					margin-right: 0px;
				}
			}
		}
		.search {
			font-size: 12px;
			line-height: 60px;
			display: inline-block;
			color: $title-color;
			margin-left: 220px;
			i {
				font-weight: 600;
			}
		}
	}
	& + section,
	& + row,
	& + div {
		margin-top: 0px;
	}
	&.navbar_fixed {
		.main_menu {
			position: fixed;
			width: 100%;
			top: -70px;
			left: 0;
			right: 0;
			background: #04091e;
			transform: translateY(70px);
			transition: transform 500ms ease, background 500ms ease;
			-webkit-transition: transform 500ms ease, background 500ms ease;
			box-shadow: 0px 3px 16px 0px rgba(0, 0, 0, 0.1);
			.navbar {
				.nav {
					.nav-item {
						.nav-link {
							line-height: 80px;
							color: #ffffff;
						}
					}
				}
			}
		}
	}
}

/* Home Banner Area css
============================================================================================ */

.open {
	.side_menu {
		right: 0px;
	}
	.canvus_menu {
		.toggle_icon {
			span {
				background: transparent !important;
				&:before {
					@include transform(rotate(45deg));
					top: 0px;
					@include transition(all 0.5s ease-in-out);
				}
				&:after {
					width: 30px;
					@include transform(rotate(-45deg));
					bottom: 0px;
					@include transition(all 0.5s ease-in-out);
				}
			}
		}
	}
}

.canvus_menu {
	overflow: hidden;
	position: absolute;
	left: 0px;
	top: 0px;
	z-index: 10;
	width: 100%;
	padding-top: 30px;
	padding-bottom: 30px;
	.toggle_icon {
		cursor: pointer;
		position: fixed;
		height: 20px;
		width: 30px;
		top: 25px;
		right: 50px;
		@include transition();
		background: transparent;
		padding: 20px;
		z-index: 9999;
		@media (max-width: 575px) {
			right: 30px;
		}
		span {
			height: 2px;
			width: 20px;
			display: block;
			background: $title-color;
			cursor: pointer;
			position: absolute;
			right: 0px;
			top: 50%;
			@include transition(all 0.5s ease-in-out);
			&:before {
				content: "";
				height: 2px;
				width: 30px;
				display: block;
				background: $title-color;
				right: 0px;
				top: -10px;
				position: absolute;
				@include transition(all 0.5s ease-in-out);
			}
			&:after {
				content: "";
				height: 2px;
				width: 25px;
				display: block;
				background: $title-color;
				right: 0px;
				bottom: -10px;
				position: absolute;
				@include transition(all 0.5s ease-in-out);
			}
		}
		&.blog {
			span {
				background: #ffffff;
				&:after,
				&:before {
					background: #ffffff;
				}
			}
		}
	}
}

.side_menu {
	position: fixed;
	right: -33%;
	top: 0px;
	height: 100%;
	background: $secondaryColor;
	width: 100%;
	max-width: 33%;
	text-align: center;
	padding-left: 20px;
	z-index: 2;
	padding-right: 20px;
	@include transition();
	opacity: .95;
	@media (max-width: 575px) {
		max-width: 75%;
		right: -75%;
	}
	.input-group {
		display: block;
		position: relative;
		input {
			width: 100%;
			border: none;
			border-radius: 0px;
			height: 40px;
			padding: 0px 28px 0px 15px;
			background: $baseColor;
			line-height: 40px;
			font-size: 12px;
			color: #fff;
			font-family: $text-font;
			outline: none;
			box-shadow: none;
			@include placeholder {
				font-size: 12px;
				color: #fff;
				font-family: $text-font;
			}
		}
		.input-group-append {
			position: absolute;
			right: 10px;
			top: 47%;
			transform: translateY(-50%);
			z-index: 4;
			.btn-outline-secondary {
				border: none;
				border-radius: 0px;
				color: #fff;
				padding: 0px;
			}
		}
	}
	.menu_right {
		// margin-top: 120px;
		position: absolute;
		left: 50%;
		top: 50%;
		@include transform(translate(-50%, -50%));

		max-height: 420px;
		@media (max-width: 1440px) {
			// margin-top: 20px;
		}
		li {
			margin-bottom: 25px;
			@media (max-width: 1440px) {
				margin-bottom: 15px;
			}
			&:last-child {
				margin-bottom: 0px;
			}
			a {
				font-size: 12px;
				font-family: $text-font;
				font-weight: bold;
				color: $title-color;
				text-transform: uppercase;
			}
			ul {
				display: none;
				li {
					text-align: right;
					margin-bottom: 10px;
					margin-left: 40px;
					a {
						color: $title-color;
						text-transform: capitalize;
					}
					&:first-child {
						margin-top: 10px;
					}
					&:hover {
						a {
							color: $title-color;
						}
					}
				}
			}
		}
	}
}

/* Home Banner Area css
============================================================================================ */
